from .worker import ValiotWorker
from .worker import QueueType, JobStatus, PollingMode, JobConfigMode
from .uploaders import update_job

# * Package name:
name = 'ValiotWorker'
# * required here for pypi upload exceptions:
__version__ = "1.4.0"
